@@ -2,14 +2,14 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from product import *
+from . import product
 
 
 def register():
     Pool.register(
-        ProductAttributeSet,
-        ProductAttribute,
-        ProductAttributeAttributeSet,
-        Template,
-        Product,
+        product.AttributeSet,
+        product.Attribute,
+        product.AttributeAttributeSet,
+        product.Template,
+        product.Product,
         module='product_attribute', type_='model')
