@@ -4,30 +4,27 @@ from trytond.model import ModelSQL, ModelView, DictSchemaMixin, fields
 from trytond.pool import PoolMeta
 from trytond.pyson import Eval
 
-__all__ = ['ProductAttributeSet', 'ProductAttribute',
-    'ProductAttributeAttributeSet', 'Template', 'Product']
 
-
-class ProductAttributeSet(ModelSQL, ModelView):
+class AttributeSet(ModelSQL, ModelView, metaclass=PoolMeta):
     "Product Attribute Set"
-    __metaclass__ = PoolMeta
     __name__ = 'product.attribute.set'
-    name = fields.Char('Name', required=True, translate=True)
+    name = fields.Char('Name', required=True, translate=True,
+        help="The main identifier of product attribute set.")
     attributes = fields.Many2Many('product.attribute-product.attribute-set',
-        'attribute_set', 'attribute', 'Attributes')
+        'attribute_set', 'attribute', 'Attributes',
+        help="Add attributes to the set.")
 
 
-class ProductAttribute(DictSchemaMixin, ModelSQL, ModelView):
+class Attribute(DictSchemaMixin, ModelSQL, ModelView, metaclass=PoolMeta):
     "Product Attribute"
-    __metaclass__ = PoolMeta
     __name__ = 'product.attribute'
     sets = fields.Many2Many('product.attribute-product.attribute-set',
-        'attribute', 'attribute_set', 'Sets')
+        'attribute', 'attribute_set', 'Sets',
+        help="Add sets to the attribute.")
 
 
-class ProductAttributeAttributeSet(ModelSQL):
+class AttributeAttributeSet(ModelSQL, metaclass=PoolMeta):
     "Product Attribute - Set"
-    __metaclass__ = PoolMeta
     __name__ = 'product.attribute-product.attribute-set'
     attribute = fields.Many2One('product.attribute', 'Attribute',
         ondelete='CASCADE', select=True, required=True)
@@ -35,14 +32,13 @@ class ProductAttributeAttributeSet(ModelSQL):
         ondelete='CASCADE', select=True, required=True)
 
 
-class Template:
-    __metaclass__ = PoolMeta
+class Template(metaclass=PoolMeta):
     __name__ = 'product.template'
-    attribute_set = fields.Many2One('product.attribute.set', 'Attribute Set')
+    attribute_set = fields.Many2One('product.attribute.set', 'Attribute Set',
+        help="Select a set of attributes to apply on the variants.")
 
 
-class Product:
-    __metaclass__ = PoolMeta
+class Product(metaclass=PoolMeta):
     __name__ = 'product.product'
     attributes = fields.Dict('product.attribute', 'Attributes',
         domain=[
@@ -53,4 +49,5 @@ class Product:
             'readonly': (~Eval('attribute_set')
                 & ~Eval('_parent_template', {}).get('attribute_set')),
             },
-        depends=['attribute_set'])
+        depends=['attribute_set'],
+        help="Add attributes to the variant.")
